@@ -498,3 +498,33 @@ int a68g_bufprt (char *dst, size_t len, const char *format, ...)
   }
 }
 
+//! @brief Take a peek at stdin.
+
+int peek_char (void)
+{
+#if defined (BUILD_WINDOWS)
+  if (kbhit ()) {
+    return getch ();
+  } else {
+    return NULL_CHAR;
+  }
+#elif defined (BUILD_LINUX)
+  struct termios tty;
+  memset (&tty, 0, sizeof (tty));
+  ASSERT (tcgetattr (STDIN_FILENO, &tty) >= 0);
+  tty.c_lflag &= ~ICANON;
+  tty.c_lflag &= ~ECHO;
+  tty.c_cc[VMIN] = 0; // Set to 1 for blocking operation.
+  tty.c_cc[VTIME] = 0;
+  ASSERT (tcsetattr (STDIN_FILENO, TCSANOW, &tty) >= 0);
+  char buf = NULL_CHAR;
+  ASSERT (read (STDIN_FILENO, &buf, 1) >= 0);
+  tty.c_lflag |= ICANON;
+  tty.c_lflag |= ECHO;
+  ASSERT (tcsetattr(STDIN_FILENO, TCSADRAIN, &tty) >= 0);
+  return (buf);
+#else
+  return getch ();
+#endif
+}
+
