@@ -49,7 +49,7 @@ DOUBLE_T ten_up_double (int expo)
     expo = 0;
     errno = EDOM;
   }
-  ABEND (expo > MAX_DOUBLE_EXPO, ERROR_INVALID_VALUE, __func__);
+  ABEND (expo > MAX_DOUBLE_EXPO, ERROR_INVALID_VALUE, NO_TEXT);
   DOUBLE_T dbl_expo = 1.0q;
   for (DOUBLE_T *dep = pow_10_double; expo != 0; expo >>= 1, dep++) {
     if (expo & 0x1) {
@@ -73,7 +73,7 @@ REAL_T ten_up (int expo)
   if (neg_expo) {
     expo = -expo;
   }
-  ABEND (expo > MAX_REAL_EXPO, ERROR_INVALID_VALUE, __func__);
+  ABEND (expo > MAX_REAL_EXPO, ERROR_INVALID_VALUE, NO_TEXT);
   REAL_T dbl_expo = 1.0;
   for (REAL_T *dep = pow_10; expo != 0; expo >>= 1, dep++) {
     if (expo & 0x1) {
