@@ -123,7 +123,7 @@ void *a68g_alloc (size_t len, const char *f, int line)
   int save = errno;
   errno = 0;
 // Allocation is platform dependent.
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64) 
+  #if defined (BUILD_WINDOWS) 
     p = _aligned_malloc (len, align);
     ABEND (p == NULL || errno != 0, "cannot allocate memory", NO_TEXT);
   #elif defined (HAVE_POSIX_MEMALIGN) 
@@ -159,8 +159,8 @@ void *a68g_alloc (size_t len, const char *f, int line)
 void a68g_free (void *z) 
 {
   if (z != NULL) {
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64) 
-    _aligned_free (z); // On WIN32/64, free cannot deallocate _aligned_malloc
+  #if defined (BUILD_WINDOWS) 
+    _aligned_free (z); // On WINDOWS, free cannot deallocate _aligned_malloc
   #else
     free (z);
   #endif
@@ -260,7 +260,7 @@ BYTE_T *get_temp_heap_space (size_t s)
 
 void get_C_stack_size (void) 
 {
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64) 
+  #if defined (BUILD_WINDOWS) 
     A68G (stack_size) = A68G_MEGA; // Guestimate
   #else
     errno = 0;
