@@ -56,27 +56,27 @@ void genie_push_undefined (NODE_T * p, MOID_T * u)
   } else if (u == M_STRING) {
     PUSH_REF (p, empty_string (p));
   } else if (u == M_LONG_INT) {
-#if (A68G_LEVEL >= 3)
-    DOUBLE_NUM_T w;
-    set_lw (w, 1);
-    PUSH_VALUE (p, w, A68G_LONG_INT);    // Because users write [~] INT !
-#else
-    (void) nil_mp (p, DIGITS (u));
-#endif
+    #if (A68G_LEVEL >= 3)
+      DOUBLE_NUM_T w;
+      set_lw (w, 1);
+      PUSH_VALUE (p, w, A68G_LONG_INT);    // Because users write [~] INT !
+    #else
+      (void) nil_mp (p, DIGITS (u));
+    #endif
   } else if (u == M_LONG_REAL) {
-#if (A68G_LEVEL >= 3)
-    genie_next_random_double (p);
-#else
-    (void) nil_mp (p, DIGITS (u));
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_next_random_double (p);
+    #else
+      (void) nil_mp (p, DIGITS (u));
+    #endif
   } else if (u == M_LONG_BITS) {
-#if (A68G_LEVEL >= 3)
-    DOUBLE_NUM_T w;
-    set_lw (w, 1);
-    PUSH_VALUE (p, w, A68G_LONG_BITS);   // Because users write [~] INT !
-#else
-    (void) nil_mp (p, DIGITS (u));
-#endif
+    #if (A68G_LEVEL >= 3)
+      DOUBLE_NUM_T w;
+      set_lw (w, 1);
+      PUSH_VALUE (p, w, A68G_LONG_BITS);   // Because users write [~] INT !
+    #else
+      (void) nil_mp (p, DIGITS (u));
+    #endif
   } else if (u == M_LONG_LONG_INT) {
     (void) nil_mp (p, DIGITS (u));
   } else if (u == M_LONG_LONG_REAL) {
@@ -84,13 +84,13 @@ void genie_push_undefined (NODE_T * p, MOID_T * u)
   } else if (u == M_LONG_LONG_BITS) {
     (void) nil_mp (p, DIGITS (u));
   } else if (u == M_LONG_COMPLEX) {
-#if (A68G_LEVEL >= 3)
-    genie_next_random_double (p);
-    genie_next_random_double (p);
-#else
-    (void) nil_mp (p, DIGITS_COMPL (u));
-    (void) nil_mp (p, DIGITS_COMPL (u));
-#endif
+    #if (A68G_LEVEL >= 3)
+      genie_next_random_double (p);
+      genie_next_random_double (p);
+    #else
+      (void) nil_mp (p, DIGITS_COMPL (u));
+      (void) nil_mp (p, DIGITS_COMPL (u));
+    #endif
   } else if (u == M_LONG_LONG_COMPLEX) {
     (void) nil_mp (p, DIGITS_COMPL (u));
     (void) nil_mp (p, DIGITS_COMPL (u));
@@ -143,7 +143,7 @@ void genie_push_undefined (NODE_T * p, MOID_T * u)
     PUSH_REF (p, A68G (skip_file));
   } else if (u == M_FILE) {
     A68G_REF *z = (A68G_REF *) STACK_TOP;
-    int size = SIZE (M_FILE);
+    size_t size = SIZE (M_FILE);
     ADDR_T pop_sp = A68G_SP;
     PUSH_REF (p, A68G (skip_file));
     A68G_SP = pop_sp;
@@ -156,13 +156,13 @@ void genie_push_undefined (NODE_T * p, MOID_T * u)
     genie_push_undefined (p, M_INT);
   } else if (u == M_SOUND) {
     A68G_SOUND *z = (A68G_SOUND *) STACK_TOP;
-    int size = SIZE (M_SOUND);
+    size_t size = SIZE (M_SOUND);
     INCREMENT_STACK_POINTER (p, size);
     FILL (z, 0, size);
     STATUS (z) = INIT_MASK;
   } else {
     BYTE_T *tos = STACK_TOP;
-    int size = SIZE_ALIGNED (u);
+    size_t size = SIZE_ALIGNED (u);
     INCREMENT_STACK_POINTER (p, size);
     FILL (tos, 0, size);
   }
@@ -199,25 +199,25 @@ void genie_jump (NODE_T * p)
     }
   }
 // Beam us up, Scotty!.
-#if defined (BUILD_PARALLEL_CLAUSE)
-  {
-    pthread_t target_id = FRAME_THREAD_ID (target_frame_pointer);
-    if (SAME_THREAD (target_id, pthread_self ())) {
-      jump_stat = FRAME_JUMP_STAT (target_frame_pointer);
-      JUMP_TO (TAG_TABLE (TAX (label))) = UNIT (TAX (label));
-      longjmp (*(jump_stat), 1);
-    } else if (SAME_THREAD (target_id, A68G_PAR (main_thread_id))) {
+  #if defined (BUILD_PARALLEL_CLAUSE)
+    {
+      pthread_t target_id = FRAME_THREAD_ID (target_frame_pointer);
+      if (SAME_THREAD (target_id, pthread_self ())) {
+        jump_stat = FRAME_JUMP_STAT (target_frame_pointer);
+        JUMP_TO (TAG_TABLE (TAX (label))) = UNIT (TAX (label));
+        longjmp (*(jump_stat), 1);
+      } else if (SAME_THREAD (target_id, A68G_PAR (main_thread_id))) {
 // A jump out of all parallel clauses back into the main program.
-      genie_abend_all_threads (p, FRAME_JUMP_STAT (target_frame_pointer), label);
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
-    } else {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PARALLEL_JUMP);
-      exit_genie (p, A68G_RUNTIME_ERROR);
+        genie_abend_all_threads (p, FRAME_JUMP_STAT (target_frame_pointer), label);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+      } else {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PARALLEL_JUMP);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
     }
-  }
-#else
-  jump_stat = FRAME_JUMP_STAT (target_frame_pointer);
-  JUMP_TO (TAG_TABLE (TAX (label))) = UNIT (TAX (label));
-  longjmp (*(jump_stat), 1);
-#endif
+  #else
+    jump_stat = FRAME_JUMP_STAT (target_frame_pointer);
+    JUMP_TO (TAG_TABLE (TAX (label))) = UNIT (TAX (label));
+    longjmp (*(jump_stat), 1);
+  #endif
 }
