@@ -105,29 +105,29 @@ MP_T *inverf_mp (NODE_T * p, MP_T * z, MP_T * x, int digs)
 // If this is not precise enough, you need more digs
 // in your entire calculation, not just in this routine.
 // Calculate an initial Newton-Raphson estimate while at it.
-#if (A68G_LEVEL >= 3)
-  DOUBLE_T y = ABS (mp_to_double (p, x, digs));
-  if (y < erf_double (5.0q)) {
-    y = inverf_double (y);
-    gdigs = FUN_DIGITS (digs);
-  } else {
-    y = 5.0q;
-    gdigs = FUN_DIGITS (2 * digs);
-  }
-  MP_T *z_g = nil_mp (p, gdigs);
-  (void) double_to_mp (p, z_g, y, A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
-#else
-  REAL_T y = ABS (mp_to_real (p, x, digs));
-  if (y < erf (4.0)) {
-    y = a68g_inverf_real (y);
-    gdigs = FUN_DIGITS (digs);
-  } else {
-    y = 4.0;
-    gdigs = FUN_DIGITS (2 * digs);
-  }
-  MP_T *z_g = nil_mp (p, gdigs);
-  (void) real_to_mp (p, z_g, y, gdigs);
-#endif
+  #if (A68G_LEVEL >= 3)
+    DOUBLE_T y = ABS (mp_to_double (p, x, digs));
+    if (y < erf_double (5.0q)) {
+      y = inverf_double (y);
+      gdigs = FUN_DIGITS (digs);
+    } else {
+      y = 5.0q;
+      gdigs = FUN_DIGITS (2 * digs);
+    }
+    MP_T *z_g = nil_mp (p, gdigs);
+    (void) double_to_mp (p, z_g, y, A68G_DOUBLE_DIG, A68G_FALSE, gdigs);
+  #else
+    REAL_T y = ABS (mp_to_real (p, x, digs));
+    if (y < erf (4.0)) {
+      y = a68g_inverf_real (y);
+      gdigs = FUN_DIGITS (digs);
+    } else {
+      y = 4.0;
+      gdigs = FUN_DIGITS (2 * digs);
+    }
+    MP_T *z_g = nil_mp (p, gdigs);
+    (void) real_to_mp (p, z_g, y, gdigs);
+  #endif
   MP_T *x_g = len_mp (p, x, digs, gdigs);
   MP_T *y_g = nil_mp (p, gdigs);
   int sign = MP_SIGN (x);
@@ -199,7 +199,7 @@ void mp_gamma_table (NODE_T *p, int digs)
     int gdigs = GAMMA_PRECISION (digs);
     REAL_T log_lim = -digs * LOG_MP_RADIX, log_error; 
     do {
-      ABEND (b >= MP_RADIX, ERROR_HIGH_PRECISION, __func__);
+      ABEND (b >= MP_RADIX, ERROR_HIGH_PRECISION, NO_TEXT);
 // error = 1 / (sqrt (b) * a68g_x_up_y (2 * M_PI, b + 0.5));
       log_error = -(log10 (b) / 2 + (b + 0.5) * log10 (2 *M_PI));
       b += 1;
