@@ -38,11 +38,11 @@
 BOOL_T folder_mode (MOID_T * m)
 {
   if (primitive_mode (m)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (m == M_COMPLEX) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -53,7 +53,7 @@ BOOL_T folder_mode (MOID_T * m)
 BOOL_T constant_collateral (NODE_T * p)
 {
   if (p == NO_NODE) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, UNIT)) {
     return (BOOL_T) (folder_mode (MOID (p)) && constant_unit (SUB (p)) && constant_collateral (NEXT (p)));
   } else {
@@ -97,7 +97,7 @@ BOOL_T constant_serial (NODE_T * p, int want)
 BOOL_T constant_argument (NODE_T * p)
 {
   if (p == NO_NODE) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, UNIT)) {
     return (BOOL_T) (folder_mode (MOID (p)) && constant_unit (p) && constant_argument (NEXT (p)));
   } else {
@@ -121,7 +121,7 @@ BOOL_T constant_call (NODE_T * p)
       }
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether constant monadic formula.
@@ -137,7 +137,7 @@ BOOL_T constant_monadic_formula (NODE_T * p)
       }
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether constant dyadic formula.
@@ -158,7 +158,7 @@ BOOL_T constant_formula (NODE_T * p)
       }
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether constant unit.
@@ -166,7 +166,7 @@ BOOL_T constant_formula (NODE_T * p)
 BOOL_T constant_unit (NODE_T * p)
 {
   if (p == NO_NODE) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (IS (p, UNIT)) {
     return constant_unit (SUB (p));
   } else if (IS (p, TERTIARY)) {
@@ -187,22 +187,22 @@ BOOL_T constant_unit (NODE_T * p)
     } else if (WIDEN_TO (p, REAL, COMPLEX)) {
       return constant_unit (SUB (p));
     } else {
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   } else if (IS (p, IDENTIFIER)) {
-    if (A68_STANDENV_PROC (TAX (p))) {
+    if (A68G_STANDENV_PROC (TAX (p))) {
       for (int k = 0; PROCEDURE (&constants[k]) != NO_GPROC; k++) {
         if (PROCEDURE (TAX (p)) == PROCEDURE (&constants[k])) {
-          return A68_TRUE;
+          return A68G_TRUE;
         }
       }
-      return A68_FALSE;
+      return A68G_FALSE;
     } else {
 // Possible constant folding.
       NODE_T *def = NODE (TAX (p));
-      BOOL_T ret = A68_FALSE;
+      BOOL_T ret = A68G_FALSE;
       if (STATUS (p) & COOKIE_MASK) {
-        diagnostic (A68_WARNING, p, WARNING_UNINITIALISED);
+        diagnostic (A68G_WARNING, p, WARNING_UNINITIALISED);
       } else {
         STATUS (p) |= COOKIE_MASK;
         if (folder_mode (MOID (p)) && def != NO_NODE && NEXT (def) != NO_NODE && IS (NEXT (def), EQUALS_SYMBOL)) {
@@ -223,7 +223,7 @@ BOOL_T constant_unit (NODE_T * p)
   } else if (IS (p, CAST)) {
     return (BOOL_T) (folder_mode (MOID (SUB (p))) && constant_unit (NEXT_SUB (p)));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -236,25 +236,25 @@ void push_denotation (NODE_T * p)
 #define PUSH_DENOTATION(mode, decl) {\
   decl z;\
   NODE_T *s = (IS (SUB (p), SHORTETY) ? NEXT_SUB (p) : SUB (p));\
-  if (genie_string_to_value_internal (p, MODE (mode), NSYMBOL (s), (BYTE_T *) & z) == A68_FALSE) {\
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_IN_DENOTATION, MODE (mode));\
+  if (genie_string_to_value_internal (p, MODE (mode), NSYMBOL (s), (BYTE_T *) & z) == A68G_FALSE) {\
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_IN_DENOTATION, MODE (mode));\
   }\
   PUSH_VALUE (p, VALUE (&z), decl);}
 
   if (MOID (p) == M_INT) {
-    PUSH_DENOTATION (INT, A68_INT);
+    PUSH_DENOTATION (INT, A68G_INT);
   } else if (MOID (p) == M_REAL) {
-    PUSH_DENOTATION (REAL, A68_REAL);
+    PUSH_DENOTATION (REAL, A68G_REAL);
   } else if (MOID (p) == M_BOOL) {
-    PUSH_DENOTATION (BOOL, A68_BOOL);
+    PUSH_DENOTATION (BOOL, A68G_BOOL);
   } else if (MOID (p) == M_CHAR) {
     if ((NSYMBOL (p))[0] == NULL_CHAR) {
-      PUSH_VALUE (p, NULL_CHAR, A68_CHAR);
+      PUSH_VALUE (p, NULL_CHAR, A68G_CHAR);
     } else {
-      PUSH_VALUE (p, (NSYMBOL (p))[0], A68_CHAR);
+      PUSH_VALUE (p, (NSYMBOL (p))[0], A68G_CHAR);
     }
   } else if (MOID (p) == M_BITS) {
-    PUSH_DENOTATION (BITS, A68_BITS);
+    PUSH_DENOTATION (BITS, A68G_BITS);
   }
 #undef PUSH_DENOTATION
 }
@@ -265,11 +265,11 @@ void push_widening (NODE_T * p)
 {
   push_unit (SUB (p));
   if (WIDEN_TO (p, INT, REAL)) {
-    A68_INT k;
-    POP_OBJECT (p, &k, A68_INT);
-    PUSH_VALUE (p, (REAL_T) VALUE (&k), A68_REAL);
+    A68G_INT k;
+    POP_OBJECT (p, &k, A68G_INT);
+    PUSH_VALUE (p, (REAL_T) VALUE (&k), A68G_REAL);
   } else if (WIDEN_TO (p, REAL, COMPLEX)) {
-    PUSH_VALUE (p, 0.0, A68_REAL);
+    PUSH_VALUE (p, 0.0, A68G_REAL);
   }
 }
 
@@ -324,7 +324,7 @@ void push_unit (NODE_T * p)
   } else if (IS (p, WIDENING)) {
     push_widening (p);
   } else if (IS (p, IDENTIFIER)) {
-    if (A68_STANDENV_PROC (TAX (p))) {
+    if (A68G_STANDENV_PROC (TAX (p))) {
       (void) (*(PROCEDURE (TAX (p)))) (p);
     } else {
 // Possible constant folding 
@@ -367,17 +367,17 @@ void constant_folder (NODE_T * p, FILE_T out, int phase)
   if (phase == L_DECLARE) {
     if (MOID (p) == M_COMPLEX) {
       char acc[NAME_SIZE];
-      A68_REAL re, im;
+      A68G_REAL re, im;
       (void) make_name (acc, CON, "", NUMBER (p));
-      A68_SP = 0;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &im, A68_REAL);
-      POP_OBJECT (p, &re, A68_REAL);
-      indentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "A68_COMPLEX %s = {", acc));
-      undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "{INIT_MASK, %.*g}", A68_REAL_WIDTH + 2, VALUE (&re)));
-      undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, ", {INIT_MASK, %.*g}", A68_REAL_WIDTH + 2, VALUE (&im)));
+      POP_OBJECT (p, &im, A68G_REAL);
+      POP_OBJECT (p, &re, A68G_REAL);
+      indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "A68G_COMPLEX %s = {", acc));
+      undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "{INIT_MASK, %.*g}", A68G_REAL_WIDTH + 2, VALUE (&re)));
+      undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, ", {INIT_MASK, %.*g}", A68G_REAL_WIDTH + 2, VALUE (&im)));
       undent (out, "};\n");
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   } else if (phase == L_EXECUTE) {
     if (MOID (p) == M_COMPLEX) {
@@ -385,69 +385,69 @@ void constant_folder (NODE_T * p, FILE_T out, int phase)
     }
   } else if (phase == L_YIELD) {
     if (MOID (p) == M_INT) {
-      A68_INT k;
-      A68_SP = 0;
+      A68G_INT k;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &k, A68_INT);
-      ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, A68_LD, VALUE (&k)) >= 0);
-      undent (out, A68 (edit_line));
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      POP_OBJECT (p, &k, A68G_INT);
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, A68G_LD, VALUE (&k)) >= 0);
+      undent (out, A68G (edit_line));
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     } else if (MOID (p) == M_REAL) {
-      A68_REAL x;
-      A68_SP = 0;
+      A68G_REAL x;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &x, A68_REAL);
+      POP_OBJECT (p, &x, A68G_REAL);
 // Mind overflowing or underflowing values.
       if (!a68g_finite_real (VALUE (&x))) {
-        A68_OPT (code_errors)++;
+        A68G_OPT (code_errors)++;
         VALUE (&x) = 0.0;
       }
-      if (VALUE (&x) == A68_REAL_MAX) {
-        undent (out, "A68_REAL_MAX");
-      } else if (VALUE (&x) == -A68_REAL_MAX) {
-        undent (out, "(-A68_REAL_MAX)");
+      if (VALUE (&x) == A68G_REAL_MAX) {
+        undent (out, "A68G_REAL_MAX");
+      } else if (VALUE (&x) == -A68G_REAL_MAX) {
+        undent (out, "(-A68G_REAL_MAX)");
       } else {
-        ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%.*g", A68_REAL_WIDTH + 2, VALUE (&x)) >= 0);
-        undent (out, A68 (edit_line));
+        ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%.*g", A68G_REAL_WIDTH + 2, VALUE (&x)) >= 0);
+        undent (out, A68G (edit_line));
       }
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     } else if (MOID (p) == M_BOOL) {
-      A68_BOOL b;
-      A68_SP = 0;
+      A68G_BOOL b;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &b, A68_BOOL);
-      ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "%s", (VALUE (&b) ? "A68_TRUE" : "A68_FALSE")) >= 0);
-      undent (out, A68 (edit_line));
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      POP_OBJECT (p, &b, A68G_BOOL);
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", (VALUE (&b) ? "A68G_TRUE" : "A68G_FALSE")) >= 0);
+      undent (out, A68G (edit_line));
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     } else if (MOID (p) == M_CHAR) {
-      A68_CHAR c;
-      A68_SP = 0;
+      A68G_CHAR c;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &c, A68_CHAR);
+      POP_OBJECT (p, &c, A68G_CHAR);
       if (VALUE (&c) == '\'') {
-        undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "'\\\''"));
+        undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "'\\\''"));
       } else if (VALUE (&c) == '\\') {
-        undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "'\\\\'"));
+        undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "'\\\\'"));
       } else if (VALUE (&c) == NULL_CHAR) {
-        undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "NULL_CHAR"));
+        undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "NULL_CHAR"));
       } else if (IS_PRINT (VALUE (&c))) {
-        undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "'%c'", (CHAR_T) VALUE (&c)));
+        undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "'%c'", (CHAR_T) VALUE (&c)));
       } else {
-        undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "(CHAR_T) %d", VALUE (&c)));
+        undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "(CHAR_T) %d", VALUE (&c)));
       }
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     } else if (MOID (p) == M_BITS) {
-      A68_BITS b;
-      A68_SP = 0;
+      A68G_BITS b;
+      A68G_SP = 0;
       push_unit (p);
-      POP_OBJECT (p, &b, A68_BITS);
-      ASSERT (a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "(UNSIGNED_T) 0x" A68_LX, VALUE (&b)) >= 0);
-      undent (out, A68 (edit_line));
-      ABEND (A68_SP > 0, ERROR_INTERNAL_CONSISTENCY, __func__);
+      POP_OBJECT (p, &b, A68G_BITS);
+      ASSERT (a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "(UNSIGNED_T) 0x" A68G_LX, VALUE (&b)) >= 0);
+      undent (out, A68G (edit_line));
+      ABEND (A68G_SP > 0, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     } else if (MOID (p) == M_COMPLEX) {
       char acc[NAME_SIZE];
       (void) make_name (acc, CON, "", NUMBER (p));
-      undentf (out, a68g_bufprt (A68 (edit_line), SNPRINTF_SIZE, "(A68_REAL *) %s", acc));
+      undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "(A68G_REAL *) %s", acc));
     }
   }
 }
